@@ -29,7 +29,8 @@ from airflow_pentaho.hooks.carte import PentahoCarteHook
 class CarteBaseOperator(BaseOperator):
     """Carte Base Operator"""
 
-    FINISHED_STATUSES = ['Finished', 'Stopped']
+    FINISHED_STATUSES = ['Finished']
+    ERRORS_STATUSES = ['Finished (with errors)', 'Stopped', 'Stopped (with errors)']
 
     DEFAULT_CONN_ID = 'pdi_default'
 
@@ -98,7 +99,7 @@ class CarteJobOperator(CarteBaseOperator):
         status_job_rs = None
         status = None
         status_desc = None
-        while not status_job_rs or status_desc not in self.FINISHED_STATUSES:
+        while not status_job_rs or status_desc not in self.FINISHED_STATUSES + self.ERRORS_STATUSES:
             status_job_rs = conn.job_status(self._get_job_name(), job_id,
                                             status_job_rs)
             status = status_job_rs['jobstatus']
@@ -106,7 +107,7 @@ class CarteJobOperator(CarteBaseOperator):
             self.log.info(self.LOG_TEMPLATE, status_desc, self.job, job_id)
             self._log_logging_string(status['logging_string'])
 
-            if status_desc not in self.FINISHED_STATUSES:
+            if status_desc not in self.FINISHED_STATUSES + self.ERRORS_STATUSES:
                 self.log.info('Sleeping 5 seconds before ask again')
                 time.sleep(5)
 
@@ -115,6 +116,11 @@ class CarteJobOperator(CarteBaseOperator):
                            self.job, job_id)
             raise AirflowException(status['error_desc'])
 
+        if status_desc in self.ERRORS_STATUSES:
+            self.log.error(self.LOG_TEMPLATE, status['status_desc'],
+                           self.job, job_id)
+            raise AirflowException(status['status_desc'])
+
 
 class CarteTransOperator(CarteBaseOperator):
     """Cart Transformation operator. Runs job on Carte service."""
